package com.dcs.hnyz.service;

import java.util.List;
import com.dcs.hnyz.domain.CommunicationProtocol;

/**
 * 通讯协议管理Service接口
 * 
 * @author hmy
 * @date 2025-04-27
 */
public interface ICommunicationProtocolService 
{
    /**
     * 查询通讯协议管理
     * 
     * @param protocolId 通讯协议管理主键
     * @return 通讯协议管理
     */
    public CommunicationProtocol selectCommunicationProtocolByProtocolId(Long protocolId);

    /**
     * 查询通讯协议管理列表
     * 
     * @param communicationProtocol 通讯协议管理
     * @return 通讯协议管理集合
     */
    public List<CommunicationProtocol> selectCommunicationProtocolList(CommunicationProtocol communicationProtocol);

    /**
     * 新增通讯协议管理
     * 
     * @param communicationProtocol 通讯协议管理
     * @return 结果
     */
    public int insertCommunicationProtocol(CommunicationProtocol communicationProtocol);

    /**
     * 修改通讯协议管理
     * 
     * @param communicationProtocol 通讯协议管理
     * @return 结果
     */
    public int updateCommunicationProtocol(CommunicationProtocol communicationProtocol);

    /**
     * 批量删除通讯协议管理
     * 
     * @param protocolIds 需要删除的通讯协议管理主键集合
     * @return 结果
     */
    public int deleteCommunicationProtocolByProtocolIds(Long[] protocolIds);

    /**
     * 删除通讯协议管理信息
     * 
     * @param protocolId 通讯协议管理主键
     * @return 结果
     */
    public int deleteCommunicationProtocolByProtocolId(Long protocolId);

    /**
     * 根据协议id查询协议名称
     * @param protocolId
     * @return
     */
    String selectProtocolNameByProtocolId(Long protocolId);

    /**
     * 查询通讯协议列表
     * @return
     */
    List<CommunicationProtocol> getCommProtocolList();

    /**
     * 修改通讯协议启用状态
     * @param cp
     * @return
     */
    int changeProtocolStatus(CommunicationProtocol cp);
}
